@@ -3,8 +3,8 @@ use rowan::ast::AstNode;
 use syntax::latex;
 
 use crate::{
-    util::{find_curly_group_word, find_curly_group_word_list, CompletionBuilder},
     CompletionItem, CompletionItemData, CompletionParams,
+    util::{CompletionBuilder, find_curly_group_word, find_curly_group_word_list},
 };
 
 pub fn complete_color_models<'a>(
