@@ -4,8 +4,8 @@ use rowan::ast::AstNode;
 use syntax::latex;
 
 use crate::{
-    util::{find_curly_group_word, CompletionBuilder, ProviderContext},
     CompletionItem, CompletionItemData, CompletionParams, EnvironmentData,
+    util::{CompletionBuilder, ProviderContext, find_curly_group_word},
 };
 
 pub fn complete_environments<'a>(
