@@ -1,14 +1,14 @@
 use base_db::{
-    semantics::{tex::LabelKind, Span},
-    util::{render_label, RenderedObject},
     DocumentData,
+    semantics::{Span, tex::LabelKind},
+    util::{RenderedObject, render_label},
 };
 use rowan::ast::AstNode;
 use syntax::latex;
 
 use crate::{
-    util::{find_curly_group_word, find_curly_group_word_list, CompletionBuilder},
     CompletionItem, CompletionItemData, CompletionParams,
+    util::{CompletionBuilder, find_curly_group_word, find_curly_group_word_list},
 };
 
 fn trim_prefix<'a>(prefix: Option<&'a str>, text: &'a str) -> &'a str {
@@ -47,7 +47,7 @@ pub fn complete_label_references<'a>(
             .iter()
             .filter(|label| label.kind == LabelKind::Definition)
         {
-            if ref_pref.map_or(false, |pref| !label.name.text.starts_with(pref)) {
+            if ref_pref.is_some_and(|pref| !label.name.text.starts_with(pref)) {
                 continue;
             }
             let labeltext = trim_prefix(ref_pref, &label.name.text);
