@@ -23,7 +23,7 @@ pub struct HighlightParams<'a> {
 
 pub fn find_all(params: &HighlightParams) -> Vec<Highlight> {
     let mut results = Vec::new();
-    label::find_highlights(&params, &mut results);
+    label::find_highlights(params, &mut results);
     results
 }
 
