@@ -157,6 +157,8 @@ pub fn parse_latexmkrc(input: &str, src_dir: &Path) -> std::io::Result<Latexmkrc
         .and_then(|(i, line)| line[i..].trim_end().strip_prefix("Version "))
         .and_then(versions::Versioning::new);
 
+    log::debug!("Detected latexmk version: {version:?}");
+
     let result = if version.is_some_and(|v| v >= versions::Versioning::new("4.84").unwrap()) {
         v484::parse_latexmkrc(input, src_dir)
     } else {
@@ -210,12 +212,8 @@ fn parse_texinputs<'a>(
         .filter_map(|path| change_root(src_dir, tmp_dir, path))
         .map(|path| src_dir.join(shellexpand::tilde(&path).as_ref()))
     {
-        eprintln!("Adding path: {path:?}");
-
         file_name_db.read_dir(path);
     }
 
-    eprintln!("File name db: {file_name_db:?}");
-
     (file_name_db, lines)
 }
