@@ -1,6 +1,6 @@
 use base_db::Workspace;
 
-use crate::util::{from_proto, to_proto, ClientFlags};
+use crate::util::{ClientFlags, from_proto, to_proto};
 
 pub fn find(
     workspace: &Workspace,
@@ -9,5 +9,10 @@ pub fn find(
 ) -> Option<lsp_types::Hover> {
     let params = from_proto::hover_params(workspace, params)?;
     let hover = ::hover::find(&params)?;
-    to_proto::hover(hover, &params.feature.document.line_index, client_flags)
+    to_proto::hover(
+        hover,
+        &params.feature.document.line_index,
+        client_flags,
+        workspace.config(),
+    )
 }
